import { ApolloClient, InMemoryCache, createHttpLink, from } from '@apollo/client';
import { onError } from '@apollo/client/link/error';

const httpLink = createHttpLink({
  uri: 'http://localhost:4000/graphql',
});

const errorLink = onError(({ graphQLErrors, networkError, operation }) => {
  if (graphQLErrors) {
    console.error('GraphQL Errors:', graphQLErrors);
    graphQLErrors.forEach(({ message, locations, path }) =>
      console.error(
        `[GraphQL error]: Message: ${message}, Location: ${locations}, Path: ${path}`
      )
    );
  }

  if (networkError) {
    console.error('Network Error:', networkError);
    console.error(`[Network error]: ${networkError}`);
    console.error('Operation:', operation);
  }
});

export const client = new ApolloClient({
  link: from([errorLink, httpLink]),
  cache: new InMemoryCache({
    typePolicies: {
      Query: {
        fields: {
          groups: {
            merge(_, incoming) {
              console.log('Merging groups:', incoming);
              return incoming;
            },
          },
          tasks: {
            merge(_, incoming) {
              console.log('Merging tasks:', incoming);
              return incoming;
            },
          },
          recentTasks: {
            merge(_, incoming) {
              console.log('Merging recent tasks:', incoming);
              return incoming;
            },
          },
          frequentTasks: {
            merge(_, incoming) {
              console.log('Merging frequent tasks:', incoming);
              return incoming;
            },
          },
        },
      },
    },
  }),
  defaultOptions: {
    watchQuery: {
      fetchPolicy: 'network-only',
      errorPolicy: 'all',
    },
    query: {
      fetchPolicy: 'network-only',
      errorPolicy: 'all',
    },
  },
});