import { Knex } from 'knex';
import { BaseRepository } from './base-repository';
import { Task } from '@shared/index';

export class TaskRepository extends BaseRepository<Task> {
  constructor(db: Knex) {
    super(db, 'tasks');
  }

  async findByGroupId(groupId: number): Promise<Task[]> {
    return await this.db(this.tableName)
      .where('group_id', groupId)
      .select('*');
  }

  async findRecent(limit: number = 10): Promise<Task[]> {
    return await this.db(this.tableName)
      .orderBy('created_at', 'desc')
      .limit(limit)
      .select('*');
  }

  async findFrequent(limit: number = 10): Promise<Task[]> {
    return await this.db(this.tableName)
      .orderBy('print_count', 'desc')
      .limit(limit)
      .select('*');
  }

  async incrementPrintCount(id: number): Promise<boolean> {
    const task = await this.findById(id);
    if (!task) return false;

    return await this.update(id, {
      print_count: task.print_count + 1,
      last_printed_at: new Date()
    });
  }
}