import { formatUtils } from '../format-utils';

describe('formatUtils', () => {
  describe('createBanner', () => {
    it('should create a banner with default length', () => {
      const banner = formatUtils.createBanner('=');
      expect(banner).toBe('='.repeat(40));
    });

    it('should create a banner with custom length', () => {
      const banner = formatUtils.createBanner('-', 32);
      expect(banner).toBe('-'.repeat(32));
    });

    it('should handle empty character', () => {
      const banner = formatUtils.createBanner('', 10);
      expect(banner).toBe('');
    });

    it('should handle zero length', () => {
      const banner = formatUtils.createBanner('*', 0);
      expect(banner).toBe('');
    });
  });

  describe('formatCheckbox', () => {
    it('should format text with checkbox', () => {
      const formatted = formatUtils.formatCheckbox('Test Item');
      expect(formatted).toBe('[ ] Test Item');
    });

    it('should handle empty text', () => {
      const formatted = formatUtils.formatCheckbox('');
      expect(formatted).toBe('[ ] ');
    });

    it('should handle text with special characters', () => {
      const formatted = formatUtils.formatCheckbox('Test: Item (123)');
      expect(formatted).toBe('[ ] Test: Item (123)');
    });
  });

  describe('formatList', () => {
    it('should format list without numbering', () => {
      const items = ['Item 1', 'Item 2', 'Item 3'];
      const formatted = formatUtils.formatList(items);
      expect(formatted).toEqual([
        '[ ] Item 1',
        '[ ] Item 2',
        '[ ] Item 3'
      ]);
    });

    it('should format list with numbering', () => {
      const items = ['Item 1', 'Item 2', 'Item 3'];
      const formatted = formatUtils.formatList(items, 1);
      expect(formatted).toEqual([
        '[ ] 1: Item 1',
        '[ ] 2: Item 2',
        '[ ] 3: Item 3'
      ]);
    });

    it('should handle empty list', () => {
      const formatted = formatUtils.formatList([]);
      expect(formatted).toEqual([]);
    });

    it('should handle list with empty items', () => {
      const items = ['', 'Item 2', ''];
      const formatted = formatUtils.formatList(items);
      expect(formatted).toEqual([
        '[ ] ',
        '[ ] Item 2',
        '[ ] '
      ]);
    });
  });

  describe('formatSection', () => {
    it('should format section with default banner', () => {
      const section = formatUtils.formatSection('Header', 'Content');
      expect(section).toEqual([
        '[ ] Header',
        '='.repeat(40),
        '',
        'Content',
        ''
      ]);
    });

    it('should format section with custom banner', () => {
      const section = formatUtils.formatSection('Header', 'Content', '-');
      expect(section).toEqual([
        '[ ] Header',
        '-'.repeat(40),
        '',
        'Content',
        ''
      ]);
    });

    it('should handle empty content', () => {
      const section = formatUtils.formatSection('Header', '');
      expect(section).toEqual([
        '[ ] Header',
        '='.repeat(40),
        '',
        '',
        ''
      ]);
    });

    it('should handle empty header', () => {
      const section = formatUtils.formatSection('', 'Content');
      expect(section).toEqual([
        '[ ] ',
        '='.repeat(40),
        '',
        'Content',
        ''
      ]);
    });
  });
});