export const formatUtils = {
  /**
   * Creates a banner line with the specified character
   * @param char Character to repeat
   * @param length Length of the banner
   * @returns Formatted banner string
   */
  createBanner(char: string, length: number = 40): string {
    return char.repeat(length);
  },

  /**
   * Formats a checkbox item with the given text
   * @param text Text to display after the checkbox
   * @returns Formatted checkbox string
   */
  formatCheckbox(text: string): string {
    return `[ ] ${text}`;
  },

  /**
   * Formats a list of items into lines with optional numbering
   * @param items List of items to format
   * @param startIndex Starting index for numbering (0 for no numbers)
   * @returns Array of formatted lines
   */
  formatList(items: string[], startIndex: number = 0): string[] {
    return items.map((item, index) => {
      const num = startIndex > 0 ? `${index + startIndex}: ` : '';
      return this.formatCheckbox(`${num}${item}`);
    });
  },

  /**
   * Formats a section with a header and content
   * @param header Section header
   * @param content Section content
   * @param bannerChar Character to use for the banner
   * @returns Array of formatted lines
   */
  formatSection(header: string, content: string, bannerChar: string = '='): string[] {
    return [
      this.formatCheckbox(header),
      this.createBanner(bannerChar),
      '',
      content,
      '',
    ];
  }
};